# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.1.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [Unreleased]

## [0.2.0] - 2025-12-11

### Removed

- Removed asynchronous API.

## [0.1.0] - 2025-12-09

### Added

- Added initial implementation.

[0.2.0]: https://github.com/lisa-sgs/artifacts/compare/v0.1.0...v0.2.0
[0.1.0]: https://github.com/lisa-sgs/artifacts/releases/tag/v0.1.0
